// ********************************************************
// ** Simple Test Sample for LAN boards
// **                    models : LE-8500X (SB-GE2)
// **                           : LE-8600X (SB-10GE)
// **                           : OP-SB89
// **                           : OP-SB89G
// **                           : OP-SB89E
// ********************************************************

#include <stdio.h>
#include "LEPC.h"
int Start()
{
    if( LEStartOnline() == LE_FAIL ){
		printf("LEStartOnline failed\n");
		return -1;
    }
    printf("LEStartOnline success\n");
    return 0;
}

int Stop()
{
    LEStop();
    printf("LEStop\n");
    return 0;
}

int EmuKey(int key)
{
    LEEmulationKey(key);
    printf("LEEmulationKey\n");
    return 0;
}

int GetCaptureBuf(){
    LE_CAPTUREBUF eBuf;
    if( LEGetCaptureBuf( &eBuf ) == LE_FAIL ){
		printf("LEGetCaptureBuf failed\n");
		return -1;
    }
    printf("LEGetCaptureBuf : Current Buf = %d\n", eBuf);
    return 0;
}

int SetCaptureBuf(int iBuf){	
	if(LESetCaptureBuf((LE_CAPTUREBUF)(iBuf)) == LE_FAIL){
		printf("LESetCaptureBuf failed\n");
		return -1;
	}
	printf("LESetCaptureBuf : %d success\n", iBuf);
	return 0;
}

void printmessage()
{
    printf("\n");
    printf("--------------------\n");
    printf("0:Exit\n");
    printf("1:Start\n");
    printf("2:Stop\n");
    printf("3:EmulationKey [0]\n");
	printf("4:Get Current Buf\n");
	printf("5:Set Capture Buf -> BUF0\n");
    printf("6:Set Capture Buf -> BUF1\n");
	printf("7:Set Capture Buf -> BUF2\n");
    printf("--------------------\n");
}

int main(int argc, char *argv[])
{
    int i;
    
    if( argc == 1){
		// connect without serial (USB only) //
		if( LEConnect("") == LE_FAIL ) 	{
			printf("LEConnect failed\n");
			return -1;
		}
		printf("LEConnect (Auto) \n");
    }
    else if( argc == 2 ){
		// connect
		if( LEConnect(argv[1]) == LE_FAIL ) 	{
			printf("LEConnect failed\n");
			return -1;
		}
		printf("LEConnect %s\n",argv[1]);
    }
    else{
		printf("usage : LEPC_sample_LAN <serial number>\n");
		return 0;
    }
    
    printmessage();
    while((i = getchar()) != EOF){
		if(i=='0'){
			break;
		}
		switch(i){
		case '1':
			Start();
			break;
		case '2':
			Stop();
			break;
		case '3':
			EmuKey(LE_REMOTE_KEY_0);
			break;
		case '4':
			GetCaptureBuf();
			break;
		case '5':
			SetCaptureBuf(LE_CAPTUREBUF_0);
			break;
		case '6':
			SetCaptureBuf(LE_CAPTUREBUF_1);
			break;
		case '7':
			SetCaptureBuf(LE_CAPTUREBUF_2);
			break;
		default:
			printmessage();
			break;
		}
    }
    
    LEDisconnect();
    return 0;
}
